module.exports = defineTest({
	description: 'Tree-shake known object prototype functions',
	expectedWarnings: ['EMPTY_BUNDLE']
});
